Points

Struct Points 

pub struct Points { /* private fields */ }
A set of points.

Implementations

Source

impl Points

pub fn new(series: Values) -> Self

pub fn shape(self, shape: MarkerShape) -> Self

Set the shape of the markers.

pub fn highlight(self) -> Self

Highlight these points in the plot by scaling up their markers.

pub fn color(self, color: impl Into<Color32>) -> Self

Set the marker’s color.

pub fn filled(self, filled: bool) -> Self

Whether to fill the marker.

pub fn stems(self, y_reference: impl Into<f32>) -> Self

Whether to add stems between the markers and a horizontal reference line.

pub fn radius(self, radius: impl Into<f32>) -> Self

Set the maximum extent of the marker around its position.

pub fn name(self, name: impl ToString) -> Self

Name of this set of points.

This name will show up in the plot legend, if legends are turned on.

Multiple plot items may share the same name, in which case they will also share an entry in the legend.